<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Admin\LicenseController;
use App\Services\Statistics\TTSService;
use App\Services\Statistics\CostsService;
use App\Services\Statistics\PaymentsService;
use App\Services\Statistics\RegistrationService;
use App\Services\Statistics\UserRegistrationMonthlyService;
use Illuminate\Http\Request;

class AdminController extends Controller
{
    private $api;

    public function __construct()
    {
        $this->api = new LicenseController();
    }

    /**
     * Display admin dashboard
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $verify = $this->api->verify_license();

        if($verify['status']!=true){
            die('Your license is invalid or not activated, please contact support.');
        }

        $year = $request->input('year', date('Y'));
        $month = $request->input('month', date('m'));

        $tts = new TTSService($year, $month);
        $cost = new CostsService($year, $month);
        $payment = new PaymentsService($year, $month);
        $registration = new RegistrationService($year, $month);
        $user_registration = new UserRegistrationMonthlyService($month);
       
        $total_data_monthly = [
            'free_minutes' => $tts->getTotalFreeMinutesUsageMonthly(),
            'paid_minutes' => $tts->getTotalPaidMinutesUsageMonthly(),
            'purchased_minutes' => $payment->getTotalPurchasedMinutesCurrentMonth(),
            'transcribe_tasks' => $tts->getTotalTasksMonthly(),
            'new_users_current_month' => $registration->getNewUsersCurrentMonth(),
            'new_users_past_month' => $registration->getNewUsersPastMonth(),
            'new_subscribers_current_month' => $registration->getNewSubscribersCurrentMonth(),
            'new_subscribers_past_month' => $registration->getNewSubscribersPastMonth(),
            'income_current_month' => $payment->getTotalPaymentsCurrentMonth(),
            'income_past_month' => $payment->getTotalPaymentsPastMonth(),
            'spending_current_month' => $cost->getTotalCostForSecondCurrentMonth(),
            'spending_past_month' => $cost->getTotalCostForSecondPastMonth(),
        ];

        $total_data_yearly = [
            'total_new_users' => $registration->getNewUsersCurrentYear(),
            'total_new_subscribers' => $registration->getNewSubscribersCurrentYear(),
            'total_income' => $payment->getTotalPaymentsCurrentYear(),
            'total_spending' => $cost->getTotalCostForSecondYearly(),
            'total_purchased_minutes' => $payment->getTotalPurchasedMinutesCurrentYear(),
            'total_purchased_minutes_used' =>$tts->getTotalPaidMinutesUsageYearly()
        ];
        
        $chart_data['total_new_users'] = json_encode($registration->getAllUsers());
        $chart_data['monthly_new_users'] = json_encode($user_registration->getRegisteredUsers());
        $chart_data['total_income'] = json_encode($payment->getPayments());
        $chart_data['total_spending'] = json_encode($cost->getSpending());

        $percentage['free_current'] = json_encode($tts->getTotalFreeMinutesUsageMonthly());
        $percentage['free_past'] = json_encode($tts->getTotalFreeMinutesUsagePastMonth());
        $percentage['paid_current'] = json_encode($tts->getTotalPaidMinutesUsageMonthly());
        $percentage['paid_past'] = json_encode($tts->getTotalPaidMinutesUsagePastMonth());
        $percentage['purchased_current'] = json_encode($payment->getTotalPurchasedMinutesCurrentMonth());
        $percentage['purchased_past'] = json_encode($payment->getTotalPurchasedMinutesPastMonth());
        $percentage['task_current'] = json_encode($tts->getTotalTasksMonthly());
        $percentage['task_past'] = json_encode($tts->getTotalTasksPastMonth());
        $percentage['users_current'] = json_encode($registration->getNewUsersCurrentMonth());
        $percentage['users_past'] = json_encode($registration->getNewUsersPastMonth());
        $percentage['subscribers_current'] = json_encode($registration->getNewSubscribersCurrentMonth());
        $percentage['subscribers_past'] = json_encode($registration->getNewSubscribersPastMonth());
        $percentage['income_current'] = json_encode($payment->getTotalPaymentsCurrentMonth());
        $percentage['income_past'] = json_encode($payment->getTotalPaymentsPastMonth());
        $percentage['spending_current'] = json_encode($cost->getTotalCostForSecondCurrentMonth());
        $percentage['spending_past'] = json_encode($cost->getTotalCostForSecondPastMonth());

        return view('admin.dashboard.index', compact('chart_data', 'percentage', 'total_data_monthly', 'total_data_yearly'));
    }
}
