<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Admin\LicenseController;
use Illuminate\Support\Facades\URL;
use Illuminate\Http\Request;
use App\Services\Statistics\TTSService;
use App\Services\Statistics\CostsService;
use Illuminate\Support\Facades\Storage;
use App\Services\GCPSTTService;
use App\Models\Language;
use App\Models\Result;
use App\Models\User;
use DataTables;

class AdminSTTController extends Controller
{
    private $api;
    private $gcp;

    public function __construct()
    {
        $this->api = new LicenseController();
        $this->gcp = new GCPSTTService();
    }

    /**
     * Display TTS dashboard
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $verify = $this->api->verify_license();

        if($verify['status']!=true){
            die('Your license is invalid or not activated, please contact support.');
        } 

        $year = $request->input('year', date('Y'));
        $month = $request->input('month', date('m'));

        $tts = new TTSService($year, $month);

        $tts_data_yearly = [
            'total_free_minutes' => $tts->getTotalFreeMinutesUsageYearly(),
            'total_paid_minutes' => $tts->getTotalPaidMinutesUsageYearly(),
            'total_words' => $tts->getTotalWordsYearly(),
            'total_file_transcribe' => $tts->getTotalFileTranscribeYearly(),
            'total_recording_transcribe' => $tts->getTotalRecordingTranscribeYearly(),
            'total_live_transcribe' => $tts->getTotalLiveTranscribeYearly(),
        ];

        $tts_data_monthly = [
            'free_minutes' => $tts->getTotalFreeMinutesUsageMonthly(),
            'paid_minutes' => $tts->getTotalPaidMinutesUsageMonthly(),
        ];

        $vendor_data = [
            'aws_month' => $tts->getAWSUsageMonthly(),
            'aws_year' => $tts->getAWSUsageYearly(),
            'gcp_month' => $tts->getGCPUsageMonthly(),
            'gcp_year' => $tts->getGCPUsageYearly(),
        ];
        
        $chart_data['free_minutes'] = json_encode($tts->getFreeMinutesUsageYearly());
        $chart_data['paid_minutes'] = json_encode($tts->getPaidMinutesUsageYearly());
        $chart_data['file_minutes'] = json_encode($tts->getFileMinutesUsage());
        $chart_data['record_minutes'] = json_encode($tts->getRecordMinutesUsage());
        $chart_data['live_minutes'] = json_encode($tts->getLiveMinutesUsage());

        $percentage['aws_year'] = json_encode($tts->getAWSUsageYearly());
        $percentage['gcp_year'] = json_encode($tts->getGCPUsageYearly());
        $percentage['free_current'] = json_encode($tts->getTotalFreeMinutesUsageMonthly());
        $percentage['free_past'] = json_encode($tts->getTotalFreeMinutesUsagePastMonth());
        $percentage['paid_current'] = json_encode($tts->getTotalPaidMinutesUsageMonthly());
        $percentage['paid_past'] = json_encode($tts->getTotalPaidMinutesUsagePastMonth());


        return view('admin.stt.dashboard.index', compact('chart_data', 'percentage', 'tts_data_yearly', 'tts_data_monthly', 'vendor_data'));
    }


    /**
     * List all file tts synthesize results
     */
    public function listResults(Request $request)
    {
        if ($request->ajax()) {
            $data = Result::all()->where('mode', '<>', 'live')->sortByDesc("created_at");
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('actions', function($row){
                        $actionBtn = '<div>
                                            <a id="'.$row["id"].'" href="'. route('admin.stt.result.show', $row['id']) .'" class="transcribeResult"><i class="fa fa-clipboard transcribe-action-buttons transcribe-result" title="View Transcript Result"></i></a>                                             
                                            <a data-toggle="modal" id="deleteResultButton" data-target="#deleteModal" href="'. route("admin.stt.result.delete", $row["id"] ). '"><i class="voice-action-buttons fa fa-close deactivate-voice" title="Delete Result"></i></a>  
                                        </div>';
                        return $actionBtn;
                    })
                    ->addColumn('created-on', function($row){
                        $created_on = '<span>'.date_format($row["created_at"], 'Y-m-d H:i:s').'</span>';
                        return $created_on;
                    })
                    ->addColumn('custom-plan-type', function($row){
                        $custom_plan = '<span class="cell-box plan-'.strtolower($row["plan_type"]).'">'.ucfirst($row["plan_type"]).'</span>';
                        return $custom_plan;
                    })
                    ->addColumn('custom-status', function($row){
                        switch ($row['status']) {
                            case 'IN_PROGRESS':
                                $value = 'In Progress';
                                break;
                            case 'FAILED':
                                $value = 'Failed';
                                break;
                            case 'COMPLETED': 
                                $value = 'Completed';
                                break;
                        }
                        $custom_voice = '<span class="cell-box transcribe-'.strtolower($row["status"]).'">'.$value.'</span>';
                        return $custom_voice;
                    }) 
                    ->addColumn('custom-mode', function($row){
                        switch ($row['mode']) {
                            case 'file':
                                $value = 'Audio File';
                                break;
                            case 'record':
                                $value = 'Recording';
                                break;
                        }
                        $custom_mode = $value;
                        return $custom_mode;
                    }) 
                    ->addColumn('username', function($row){
                        if ($row["user_id"]) {
                            $username = '<span>'.User::find($row["user_id"])->name.'</span>';
                            return $username;
                        } else {
                            return $row["user_id"];
                        }                       
                    })
                    ->addColumn('custom-length', function($row){
                        $custom_voice = '<span>'.gmdate("H:i:s", $row['length']).'</span>';
                        return $custom_voice;
                    })   
                    ->addColumn('download', function($row){
                        $result = '<a class="result-download" href="' . $row['file_url'] . '" download title="Download Audio"><i class="fa fa-cloud-download transcribe-action-buttons transcribe-result"></i></a>';
                        return $result;
                    })
                    ->addColumn('single', function($row){
                        $result = '<button type="button" class="result-play" title="Play Audio" onclick="resultPlay(this)" src="' . $row['file_url']. '" type="'. $row['audio_type'].'" id="'. $row['id'] .'"><i class="fa fa-play"></i></button>';
                        return $result;
                    })
                    ->addColumn('result', function($row){
                        $result = $row['file_url'];
                        return $result;
                    })
                    ->addColumn('custom-language', function($row) {
                        $language = '<span class="vendor-image-sm overflow-hidden"><img class="mr-2" src="' . URL::asset($row['language_flag']) . '">'. $row['language'] .'<img alt="vendor" class="rounded-circle ml-2" src="' . URL::asset($row['vendor_img']) . '"></span> ';            
                        return $language;
                    })
                    ->rawColumns(['actions', 'custom-plan-type', 'created-on', 'username', 'custom-status', 'custom-mode', 'custom-length', 'result', 'custom-language', 'download', 'single'])
                    ->make(true);
                    
        }

        return view('admin.stt.results.index');
    }


    /**
     * List all live tts synthesize results
     */
    public function listLiveResults(Request $request)
    {
        if ($request->ajax()) {
            $data = Result::all()->where('mode', 'live')->sortByDesc("created_at");
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('actions', function($row){
                        $actionBtn = '<div>
                                            <a id="'.$row["id"].'" href="#" class="transcribeResult"><i class="fa fa-clipboard transcribe-action-buttons transcribe-result" title="Transcript Result"></i></a>
                                            <a data-toggle="modal" id="deleteResultButton" data-target="#deleteModal" href="'. route("admin.stt.result.delete", $row["id"] ). '"><i class="voice-action-buttons fa fa-close deactivate-voice" title="Delete Result"></i></a>  
                                        </div>';
                        return $actionBtn;
                    })
                    ->addColumn('created-on', function($row){
                        $created_on = '<span>'.date_format($row["created_at"], 'Y-m-d H:i:s').'</span>';
                        return $created_on;
                    })
                    ->addColumn('custom-plan-type', function($row){
                        $custom_plan = '<span class="cell-box plan-'.strtolower($row["plan_type"]).'">'.ucfirst($row["plan_type"]).'</span>';
                        return $custom_plan;
                    })
                    ->addColumn('custom-mode', function($row){
                        $custom_mode = 'Live Transcribe';
                        return $custom_mode;
                    }) 
                    ->addColumn('username', function($row){
                        if ($row["user_id"]) {
                            $username = '<span>'.User::find($row["user_id"])->name.'</span>';
                            return $username;
                        } else {
                            return $row["user_id"];
                        }                       
                    })
                    ->addColumn('custom-length', function($row){
                        $custom_voice = '<span>'.gmdate("H:i:s", $row['length']).'</span>';
                        return $custom_voice;
                    })   
                    ->addColumn('vendor', function($row){
                        $path = URL::asset($row['vendor_img']);
                        $vendor = '<div class="vendor-image-sm overflow-hidden"><img alt="vendor" class="rounded-circle" src="' . $path . '"></div>';
                        return $vendor;
                    })
                    ->addColumn('custom-language', function($row) {
                        $language = '<span class="vendor-image-sm overflow-hidden"><img alt="vendor" class="mr-2" src="' . URL::asset($row['language_flag']) . '">'. $row['language'] .'</span> ';                        
                        return $language;
                    })
                    ->rawColumns(['actions', 'custom-plan-type', 'created-on', 'username', 'custom-mode', 'custom-length', 'vendor', 'custom-language'])
                    ->make(true);
                    
        }

        return view('admin.stt.results.live');
    }

    
    /**
     * Display selected result details
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Result $id)
    {   
        $end_time = gmdate("H:i:s", $id->length);

        $data['type'] = json_encode($id->speaker_identity);
        $data['raw'] = json_encode($id->raw);
        $data['text'] = json_encode($id->text);
        $data['url'] = json_encode($id->file_url);
        $data['vendor'] = json_encode($id->vendor);
        $data['end_time'] = json_encode($end_time);

        $task_type = ($id->speaker_identity == 'true') ? 'Speaker Identification' : 'Standard';

        return view('admin.stt.results.show', compact('id', 'data', 'task_type'));  
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $result = Result::where('id', $id)->firstOrFail();  

        if ($result->mode != 'live') {
            if ($result->vendor == 'aws') {
                $object = 'aws/' . $result->task_id . '.' . $result->format;                    
                Storage::disk('s3')->delete($object);

                $response = $result->task_id . '.json';
                $exists = Storage::disk('s3')->has($response);
                if ($exists) {
                    Storage::disk('s3')->delete($response);
                } 

            } elseif ($result->vendor == 'gcp') {
                $this->gcp->deleteObject($result->task_id, $result->format);
            }
        }

        $result->delete();

        return redirect()->route('admin.stt.results')->with('success', 'Synthesize record was deleted successfully');       
    }

    public function delete($id)
    {   
        $result = Result::where('id', $id)->firstOrFail();

        return view('admin.stt.results.delete', compact('result'));     
    }


    /**
     * List all stt languages
     */
    public function languages(Request $request)
    {
        if ($request->ajax()) {
            $data = Language::all();
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('actions', function($row){
                        $actionBtn = '<div>      
                                            <a data-toggle="modal" id="changeLanguageNameButton" data-target="#changeNameModal" href="'. route("admin.stt.languages.edit", $row["id"] ). '"><i class="fa fa-edit voice-action-buttons rename-voice" title="Rename Language"></i></a>       
                                            <a data-toggle="modal" id="activateVoiceButton" data-target="#activateModal" href="'. route("admin.stt.languages.activate.show", $row["id"] ). '"><i class="fa fa-check voice-action-buttons activate-voice" title="Activate Language"></i></a>
                                            <a data-toggle="modal" id="deactivateVoiceButton" data-target="#deactivateModal" href="'. route("admin.stt.languages.deactivate.show", $row["id"] ). '"><i class="voice-action-buttons fa fa-close deactivate-voice" title="Deactivate Language"></i></a>  
                                        </div>';
                        return $actionBtn;
                    })
                    ->addColumn('created-on', function($row){
                        $created_on = '<span>'.date_format($row["updated_at"], 'Y-m-d H:i:s').'</span>';
                        return $created_on;
                    })
                    ->addColumn('custom-type', function($row){
                        $custom_voice = '<span class="cell-box type-'.strtolower($row["type"]).'">'.ucfirst($row["type"]).'</span>';
                        return $custom_voice;
                    })
                    ->addColumn('custom-status', function($row){
                        $custom_voice = '<span class="cell-box status-'.strtolower($row["status"]).'">'.ucfirst($row["status"]).'</span>';
                        return $custom_voice;
                    })
                    ->addColumn('speaker', function($row){
                        $speaker = ucfirst($row["speaker_identity"]);
                        return $speaker;
                    })
                    ->addColumn('vendor', function($row){
                        $path = URL::asset($row['vendor_img']);
                        $vendor = '<div class="vendor-image-sm overflow-hidden"><img alt="vendor" class="rounded-circle" src="' . $path . '"></div>';
                        return $vendor;
                    })
                    ->rawColumns(['actions', 'created-on', 'custom-type', 'vendor', 'custom-status', 'speaker'])
                    ->make(true);
                    
        }

        return view('admin.stt.languages.index');
    }


    /**
     * Update the specified language name.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function languageUpdate($id)
    {   

        $result = Language::where('id', $id)->firstOrFail();

        $result->update(['language' => request('language-name')]);

        return redirect()->route('admin.stt.languages')->with('success', 'Language name was successfully updated');   
    }


    /**
     * Edit the specified language.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function languageEdit($id)
    {   
        $result = Language::where('id', $id)->firstOrFail();

        return view('admin.stt.languages.edit', compact('result'));     
    }


    /**
     * Enable the specified language.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function languageActivate($id)
    {
        $result = Language::where('id', $id)->firstOrFail();  

        if ($result->status == 'active') {
            return redirect()->route('admin.stt.languages')->with('error', 'Language is already activated'); 
        }

        $result->update(['status' => 'active']);

        return redirect()->route('admin.stt.languages')->with('success', 'Language was successfully activated');       
    }

    public function languageShowActivate($id)
    {   
        $result = Language::where('id', $id)->firstOrFail();

        return view('admin.stt.languages.activate', compact('result'));     
    }


    /**
     * Enable all languages.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function languagesActivateAll()
    {
        Language::query()->update(['status' => 'active']); 

        return redirect()->route('admin.stt.languages')->with('success', 'All languages were successfully activated');         
    }


    /**
     * Disable the specified language.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function languageDeactivate($id)
    {
        $result = Language::where('id', $id)->firstOrFail();  

        if ($result->status == 'deactive') {
            return redirect()->route('admin.stt.languages')->with('error', 'Language is already deactivated'); 
        }

        $result->update(['status' => 'deactive']);

        return redirect()->route('admin.stt.languages')->with('success', 'Language was successfully deactivated');       
    }

    public function languageShowDeactivate($id)
    {   
        $result = Language::where('id', $id)->firstOrFail();

        return view('admin.stt.languages.deactivate', compact('result'));     
    }


    /**
     * Disable all languages.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function languagesDeactivateAll()
    {
        Language::query()->update(['status' => 'deactive']); 

        return redirect()->route('admin.stt.languages')->with('success', 'All languages were successfully deactivated');       
    }


    public function transcript(Request $request)
    {   
        if ($request->ajax()) {

            if ($request->json && !$request->speaker) {
                $data = Result::where('id', $request->id)->pluck('raw');
            } elseif ($request->json && $request->speaker) {
                $data['raw'] = Result::where('id', $request->id)->pluck('raw');
                $data['speaker'] = Result::where('id', $request->id)->pluck('speaker_identity');
                $data['vendor'] = Result::where('id', $request->id)->pluck('vendor');
            } else {
                $data = Result::where('id', $request->id)->pluck('text');
            }
           
            return $data;
        }   
    }
    

    public function transcriptSave(Request $request)
    {   
        if ($request->ajax()) {

            $data = Result::where('id', $request->id)->first();
            $data->update(['text' => $request->text]);
            
            return 'Transcript was successfully updated and saved.';
        }   
    }
}
