<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Mail;
use App\Models\PrepaidPlan;
use App\Models\Setting;
use App\Models\Plan;
use App\Models\Blog;
use App\Models\Faq;
use DB;

class HomeController extends Controller
{
    /**
     * Show home page
     */
    public function index()
    {
        $information = $this->metadataInformation();

        return view('home', compact('information'));
    }


    /**
     * Display terms & conditions page
     * 
     */
    public function termsAndConditions() 
    {
        $information = $this->metadataInformation();

        return view('service-terms', compact('information'));
    }


    /**
     * Display privacy policy page
     * 
     */
    public function privacyPolicy() 
    {
        $information = $this->metadataInformation();

        return view('privacy-policy', compact('information'));
    }


    /**
     * Frontend about us
     * 
     */
    public function about()
    {
        $information = $this->metadataInformation();

        return view('about', compact('information'));
    }


    /**
     * Frontend plan prices
     * 
     */
    public function pricing()
    {
        $information = $this->metadataInformation();

        $plan = Plan::count();

        $prepaid_exists = PrepaidPlan::count();

        $subscriptions = Plan::where('plan_type', 'subscription')
                             ->where('status', 'active')->get();
        $prepaids = PrepaidPlan::where('plan_type', 'prepaid')
                        ->where('status', 'active')->get();

        return view('pricing', compact('information', 'plan', 'prepaid_exists', 'subscriptions', 'prepaids'));
    }


    /**
     * Frontend blogs
     * 
     */
    public function blogs()
    {
        $blog_exists = Blog::count();

        $blogs = Blog::where('status', 'published')->get();

        $information = $this->metadataInformation();

        return view('blogs', compact('information', 'blog_exists', 'blogs'));
    }


    /**
     * Frontend show blog
     * 
     */
    public function blogShow($slug)
    {
        $blog = Blog::where('url', $slug)->firstOrFail();

        $information_rows = ['js', 'css'];
        $information = [];
        $settings = Setting::all();

        foreach ($settings as $row) {
            if (in_array($row['name'], $information_rows)) {
                $information[$row['name']] = $row['value'];
            }
        }

        $information['author'] = $blog->created_by;
        $information['title'] = $blog->title;
        $information['keywords'] = $blog->keywords;
        $information['description'] = $blog->title;

        return view('blog-show', compact('information', 'blog'));
    }


    /**
     * Frontend faqs
     * 
     */
    public function faqs()
    {
        $faq_exists = Faq::count();
        
        $faqs = Faq::where('status', 'visible')->get();
        
        $categories = DB::table('categories')
                ->join('faqs', 'faqs.category', '=', 'categories.name')
                ->where('categories.group', 'faq')
                ->select(DB::raw('distinct(categories.name)'))
                ->get(); 

        $information = $this->metadataInformation();

        return view('faqs', compact('information', 'faq_exists', 'faqs', 'categories'));
    }


    /**
     * Frontend contact us form show
     * 
     */
    public function contactForm()
    {
        $information = $this->metadataInformation();

        return view('contact', compact('information'));
    }


    /**
     * Frontend contact us form record
     * 
     */
    public function contact()
    {
        request()->validate([
            'name' => 'required|string',
            'email' => 'required|email',
            'category' => 'required',
            'message' => 'required|string',
        ]);

        if (config('services.google.recaptcha.enable') == 'on') {

            $recaptchaResult = $this->reCaptchaCheck(request('recaptcha'));

            if ($recaptchaResult->success != true) {
                return redirect()->back()->with('error', 'Google reCaptcha Validation has Failed');
            }

            if ($recaptchaResult->score >= 0.5) {

                try {
                    Mail::send(array(), array(), function ($message) {
                        $message->from(config('mail.from.address'), request('name'));
                        $message->replyTo(request('email'), request('name'));
                        $message->to(config('mail.from.address'), request('name'));
                        $message->subject(request('category'));
                        $message->setBody(request('message'));
                    });
                } catch (\Exception $e) {
                    return redirect()->back()->with('error', 'SMTP settings were not set yet, please contact support team. ' . $e->getMessage());
                }

                if (Mail::failures()) {
                    return redirect()->back()->with('error', 'Sending email failed, please try again.');
                }

                return redirect()->back()->with('success', 'Email was successfully sent');

            } else {
                return redirect()->back()->with('error', 'Google reCaptcha Validation has Failed');
            }
        
        } else {

            try {
                Mail::send(array(), array(), function ($message) {
                    $message->from(config('mail.from.address'), request('name'));
                    $message->replyTo(request('email'), request('name'));
                    $message->to(config('mail.from.address'), request('name'));
                    $message->subject(request('category'));
                    $message->setBody(request('message'));
                });
            } catch (\Exception $e) {
                return redirect()->back()->with('error', 'SMTP settings were not set yet, please contact support team. ' . $e->getMessage());
            }

            if (Mail::failures()) {
                return redirect()->back()->with('error', 'Sending email failed, please try again.');
            }

            return redirect()->back()->with('success', 'Email was successfully sent');
        }  
    }


    /**
     * Verify reCaptch for frontend contact us page (if enabled)
     * 
     */
    private function reCaptchaCheck($recaptcha)
    {
        $url = 'https://www.google.com/recaptcha/api/siteverify';
        $remoteip = $_SERVER['REMOTE_ADDR'];

        $data = [
                'secret' => config('services.google.recaptcha.secret_key'),
                'response' => $recaptcha,
                'remoteip' => $remoteip
        ];

        $options = [
                'http' => [
                'header' => "Content-type: application/x-www-form-urlencoded\r\n",
                'method' => 'POST',
                'content' => http_build_query($data)
                ]
        ];

        $context = stream_context_create($options);
        $result = file_get_contents($url, false, $context);
        $resultJson = json_decode($result);

        return $resultJson;
    }


    public function metadataInformation()
    {
        $information_rows = ['title', 'author', 'keywords', 'description', 'js', 'css'];
        $information = [];
        $settings = Setting::all();

        foreach ($settings as $row) {
            if (in_array($row['name'], $information_rows)) {
                $information[$row['name']] = $row['value'];
            }
        }

        return $information;
    }

}
