<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use App\Http\Controllers\Admin\LicenseController;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;
use App\Services\GCPSTTService;
use Illuminate\Http\Request;
use App\Models\Result;
use DataTables;

class STTResultController extends Controller
{
    private $api;
    private $gcp;

    public function __construct()
    {
        $this->api = new LicenseController();
        $this->gcp = new GCPSTTService();
    }

    /** 
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {   
        $verify = $this->api->verify_license();

        if($verify['status']!=true){
            die('Your license is invalid or not activated, please contact support.');
        }

        if ($request->ajax()) {
            $data = Result::where('user_id', Auth::user()->id)->where('mode', '<>', 'live')->latest()->get();
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('actions', function($row){
                        $actionBtn = '<div>
                                            <a id="'.$row["id"].'" href="'. route('user.stt.results.show', $row['id']) .'" class="transcribeResult"><i class="fa fa-clipboard transcribe-action-buttons transcribe-result" title="View Transcript Result"></i></a> 
                                            <a data-toggle="modal" id="deleteResultButton" data-target="#deleteModal" href="'. route("user.stt.result.delete", $row["id"] ). '"><i class="transcribe-action-buttons fa fa-close deactivate-voice" title="Delete Result"></i></a>  
                                        </div>';
                        return $actionBtn;
                    })
                    ->addColumn('created-on', function($row){
                        $created_on = '<span>'.date_format($row["created_at"], 'Y-m-d H:i:s').'</span>';
                        return $created_on;
                    })
                    ->addColumn('custom-status', function($row){
                        switch ($row['status']) {
                            case 'IN_PROGRESS':
                                $value = 'In Progress';
                                break;
                            case 'FAILED':
                                $value = 'Failed';
                                break;
                            case 'COMPLETED': 
                                $value = 'Completed';
                                break;
                            default: 
                                $value = '';
                                break;
                        }
                        $custom_voice = '<span class="cell-box transcribe-'.strtolower($row["status"]).'">'.$value.'</span>';
                        return $custom_voice;
                    })      
                    ->addColumn('custom-mode', function($row) {
                        switch ($row['mode']) {
                            case 'file':
                                $value = 'Audio File';
                                break;
                            case 'record':
                                $value = 'Recording';
                                break;
                            default: 
                                $value = '';
                                break;
                        }
                        $custom_mode = $value;
                        return $custom_mode;
                    })   
                    ->addColumn('custom-length', function($row) {
                        $custom_voice = '<span>'.gmdate("H:i:s", $row['length']).'</span>';
                        return $custom_voice;
                    })         
                    ->addColumn('result', function($row) {
                        $result = $row['file_url'];
                        return $result;
                    })
                    ->addColumn('download', function($row) {                        
                        $result = '<a class="result-download" href="' . $row['file_url'] . '" download title="Download Audio"><i class="fa fa-cloud-download transcribe-action-buttons transcribe-result"></i></a>';
                        return $result;
                    })
                    ->addColumn('single', function($row) {
                        $result = '<button type="button" class="result-play" onclick="resultPlay(this)" title="Play Audio" src="' . $row['file_url'] . '" type="'. $row['audio_type'].'" id="'. $row['id'] .'"><i class="fa fa-play"></i></button>';
                        return $result;
                    })
                    ->addColumn('custom-language', function($row) {
                        if (config('stt.vendor_logos') == 'show') {
                            $language = '<span class="vendor-image-sm overflow-hidden"><img alt="vendor" class="mr-2" src="' . URL::asset($row['language_flag']) . '">'. $row['language'] .'<img alt="vendor" class="rounded-circle ml-2" src="' . URL::asset($row['vendor_img']) . '"></span> ';
                        } else {
                            $language = '<span class="vendor-image-sm overflow-hidden"><img alt="vendor" class="mr-2" src="' . URL::asset($row['language_flag']) . '">'. $row['language'] .'</span> ';
                        }                         
                        return $language;
                    })
                    ->addColumn('type', function($row){ 
                        $result = ($row['speaker_identity'] == 'true') ? 'Speaker Identification' : 'Standard';
                        return $result;
                    })
                    ->rawColumns(['actions', 'created-on', 'custom-status', 'custom-length', 'custom-language', 'custom-mode', 'result', 'download', 'single', 'type'])
                    ->make(true);
                    
        }

        return view('user.stt-results.index');
    }


    /** 
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function live(Request $request)
    {   
        $verify = $this->api->verify_license();

        if($verify['status']!=true){
            die('Your license is invalid or not activated, please contact support.');
        }

        # Today's STT Results for Datatable
        if ($request->ajax()) {
            $data = Result::where('user_id', Auth::user()->id)->where('mode', 'live')->latest()->get();
            return Datatables::of($data)
                    ->addIndexColumn()
                    ->addColumn('actions', function($row){
                        $actionBtn = '<div>
                                            <a id="'.$row["id"].'" href="#" class="transcribeResult"><i class="fa fa-clipboard transcribe-action-buttons transcribe-result" title="Edit Transcript"></i></a>                                          
                                            <a data-toggle="modal" id="deleteResultButton" data-target="#deleteModal" href="'. route("user.stt.result.delete", $row["id"] ). '"><i class="transcribe-action-buttons fa fa-close deactivate-voice" title="Delete Result"></i></a>  
                                        </div>';
                        return $actionBtn;
                    })
                    ->addColumn('created-on', function($row){
                        $created_on = '<span>'.date_format($row["created_at"], 'Y-m-d H:i:s').'</span>';
                        return $created_on;
                    })
                    ->addColumn('custom-mode', function($row){
                        $custom_mode = 'Live Transcribe';
                        return $custom_mode;
                    })
                    ->addColumn('custom-length', function($row){
                        $custom_voice = '<span>'.gmdate("H:i:s", $row['length']).'</span>';
                        return $custom_voice;
                    })  
                    ->addColumn('vendor', function($row){
                        $path = URL::asset($row['vendor_img']);
                        $vendor = '<div class="vendor-image-sm overflow-hidden"><img alt="vendor" src="' . $path . '"></div>';
                        return $vendor;
                    })
                    ->addColumn('custom-language', function($row) {
                        $language = '<span class="vendor-image-sm overflow-hidden"><img alt="vendor" class="mr-2" src="' . URL::asset($row['language_flag']) . '">'. $row['language'] .'</span> ';                         
                        return $language;
                    })
                    ->rawColumns(['actions', 'created-on', 'vendor', 'custom-mode', 'custom-length', 'custom-language'])
                    ->make(true);
                    
        }

        $vendor_logo['status'] = json_encode((config('stt.vendor_logos') == 'show') ? 'show' : 'none');

        return view('user.stt-results.live', compact('vendor_logo'));
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show(Result $id)
    {
        if ($id->user_id == Auth::user()->id){

            $end_time = gmdate("H:i:s", $id->length);

            $data['type'] = json_encode($id->speaker_identity);
            $data['raw'] = json_encode($id->raw);
            $data['text'] = json_encode($id->text);
            $data['url'] = json_encode($id->file_url);
            $data['vendor'] = json_encode($id->vendor);
            $data['end_time'] = json_encode($end_time);

            $task_type = ($id->speaker_identity == 'true') ? 'Speaker Identification' : 'Standard';

            return view('user.stt-results.show', compact('id', 'data', 'task_type'));     

        } else{
            return redirect()->route('user.stt.results');
        }
      
    }
    

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $result = Result::where('id', $id)->firstOrFail();  

        if ($result->user_id == Auth::user()->id){

            if ($result->mode != 'live') {
                if ($result->vendor == 'aws') {
                    $object = 'aws/' . $result->task_id . '.' . $result->format;                    
                    Storage::disk('s3')->delete($object);

                    $response = $result->task_id . '.json';
                    $exists = Storage::disk('s3')->has($response);
                    if ($exists) {
                        Storage::disk('s3')->delete($response);
                    } 

                } elseif ($result->vendor == 'gcp') {
                    $this->gcp->deleteObject($result->task_id, $result->format);
                }
            }           

            $result->delete();

            return redirect()->route('user.stt.results')->with('success', 'Transcribe result was deleted successfully');
        
        } else{
            return redirect()->route('user.stt.results');
        }               
    }

    public function delete($id)
    {   
        $result = Result::where('id', $id)->firstOrFail();

        if ($result->user_id == Auth::user()->id){

            return view('user.stt-results.delete', compact('result'));     

        } else{
            return redirect()->route('user.stt.results');
        }    
    }


    public function transcript(Request $request)
    {   
        if ($request->ajax()) {

            if ($request->json && !$request->speaker) {
                $data = Result::where('id', $request->id)->pluck('raw');
            } elseif ($request->json && $request->speaker) {
                $data['raw'] = Result::where('id', $request->id)->pluck('raw');
                $data['speaker'] = Result::where('id', $request->id)->pluck('speaker_identity');
                $data['vendor'] = Result::where('id', $request->id)->pluck('vendor');
            } else {
                $data = Result::where('id', $request->id)->pluck('text');
            }
           
            return $data;
        }   
    }


    public function transcriptSave(Request $request)
    {   
        if ($request->ajax()) {

            $data = Result::where('id', $request->id)->first();
            $data->update(['text' => $request->text]);
            
            return 'Transcript was successfully updated and saved.';
        }   
    }
}
