<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\URL;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;
use App\Models\Result;
use DataTables;

class SearchController extends Controller
{
    /**
     * Show search results
     */
    public function index(Request $request)
    {
        $results = Result::where('user_id', Auth::user()->id)->where( 'text', 'LIKE', '%' . $request->keyword . '%' )->latest()->get();
        
        $data =  Datatables::of($results)
                ->addIndexColumn()
                ->addColumn('created-on', function($row){
                    $created_on = '<span>'.date_format($row["created_at"], 'Y-m-d H:i:s').'</span>';
                    return $created_on;
                })
                ->addColumn('custom-status', function($row){
                    switch ($row['status']) {
                        case 'IN_PROGRESS':
                            $value = 'In Progress';
                            break;
                        case 'FAILED':
                            $value = 'Failed';
                            break;
                        case 'COMPLETED': 
                            $value = 'Completed';
                            break;
                    }
                    $custom_voice = '<span class="cell-box transcribe-'.strtolower($row["status"]).'">'.$value.'</span>';
                    return $custom_voice;
                })  
                ->addColumn('custom-mode', function($row) {
                    switch ($row['mode']) {
                        case 'file':
                            $value = 'Audio File';
                            break;
                        case 'record':
                            $value = 'Recording';
                            break;
                        case 'live':
                            $value = 'Live Transcribe';
                            break;
                    }
                    $custom_mode = $value;
                    return $custom_mode;
                })   
                ->addColumn('custom-length', function($row) {
                    $custom_voice = '<span>'.gmdate("H:i:s", $row['length']).'</span>';
                    return $custom_voice;
                })                     
                ->addColumn('result', function($row){
                    $result = $row['file_url'];
                    return $result;
                })
                ->addColumn('vendor', function($row){
                    $path = URL::asset($row['vendor_img']);
                    $vendor = '<div class="vendor-image-sm overflow-hidden"><img alt="vendor" class="rounded-circle" src="' . $path . '"></div>';
                    return $vendor;
                })
                ->rawColumns(['created-on', 'custom-status', 'result', 'custom-mode', 'custom-length', 'vendor'])
                ->make(true);
        

        $searchValue = $request->keyword;
        $data = json_encode($data);

        return view('user.search.index', compact('searchValue', 'data'));
    }
}
