<?php

namespace App\Services\Statistics;

use DB;

class CostsService 
{
    private $year;
    private $month;

    public function __construct(int $year = null, int $month = null) 
    {
        $this->year = $year;
        $this->month = $month;
    }


    public function getCostPerSecond($id)
    {   
        $cost = DB::table('results')
                    ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                    ->where('results.id', $id)
                    ->select(DB::raw('(results.length * vendors.cost) as data'))              
                    ->get();  

        return $cost;
    }


    public function getSpending()
    {
        $spending = DB::table('results')
                ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                ->whereYear('results.created_at', $this->year)
                ->select(DB::raw('sum(results.length * vendors.cost) as data'), DB::raw("MONTH(results.created_at) month"))
                ->groupBy('month')
                ->orderBy('month')
                ->get(); 
        
        $data = [];

        for($i = 1; $i <= 12; $i++) {
            $data[$i] = 0;
        }

        foreach ($spending as $row) {	
            $month = $row->month;
            $data[$month] = number_format((float)$row->data, 2);            	   
        }
        
        return $data;
    }


    public function getTotalCostForSecondYearly()
    {   
        $data = DB::table('results')
                    ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                    ->whereYear('results.created_at', $this->year)
                    ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                    ->get();  

        $cost = get_object_vars($data[0]);
             
        return $cost['data'];

       
    }


    public function getTotalCostForSecondCurrentMonth()
    {   
        $data= DB::table('results')
                        ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                        ->whereMonth('results.created_at', $this->month)
                        ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                        ->get();   
        
        $cost = get_object_vars($data[0]);

        return $cost['data'];
    }


    public function getTotalCostForSecondPastMonth()
    {   
        $date = \Carbon\Carbon::now();
        $pastMonth =  $date->subMonth()->format('m');

        $data= DB::table('results')
                        ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                        ->whereMonth('results.created_at', $pastMonth)
                        ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                        ->get();   
        
        $cost = get_object_vars($data[0]);       

        return $cost['data'];
    }


    public function getTotalAWSCostCurrentMonth()
    {   
        $data= DB::table('results')
                        ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                        ->where('results.vendor', 'aws')
                        ->whereMonth('results.created_at', $this->month)
                        ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                        ->get();   
        
        $cost = get_object_vars($data[0]);

        return $cost['data'];
    }


    public function getTotalAWSCostCurrentYear()
    {   
        $data= DB::table('results')
                        ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                        ->where('results.vendor', 'aws')
                        ->whereYear('results.created_at', $this->year)
                        ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                        ->get();   
        
        $cost = get_object_vars($data[0]);

        return $cost['data'];
    }


    public function getTotalGCPCostCurrentMonth()
    {   
        $data= DB::table('results')
                        ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                        ->where('results.vendor', 'gcp')
                        ->whereMonth('results.created_at', $this->month)
                        ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                        ->get();   
        
        $cost = get_object_vars($data[0]);

        return $cost['data'];
    }


    public function getTotalGCPCostCurrentYear()
    {   
        $data= DB::table('results')
                        ->join('vendors', 'results.vendor', '=', 'vendors.vendor')
                        ->where('results.vendor', 'gcp')
                        ->whereYear('results.created_at', $this->year)
                        ->select(DB::raw('sum(results.length * vendors.cost) as data'))
                        ->get();   
        
        $cost = get_object_vars($data[0]);

        return $cost['data'];
    }
}