<?php

namespace App\Services\Statistics;

use App\Models\Payment;
use DB;

class PaymentsService 
{
    private $year;
    private $month;

    public function __construct(int $year, int $month) 
    {
        $this->year = $year;
        $this->month = $month;
    }


    public function getPayments()
    {
        $payments = Payment::select(DB::raw("sum(amount) as data"), DB::raw("MONTH(created_at) month"))
                ->whereYear('created_at', $this->year)
                ->where('status', 'Success')
                ->groupBy('month')
                ->orderBy('month')
                ->get()->toArray();  
        
        $data = [];

        for($i = 1; $i <= 12; $i++) {
            $data[$i] = 0;
        }

        foreach ($payments as $row) {				            
            $month = $row['month'];
            $data[$month] = intval($row['data']);
        }
        
        return $data;
    }


    public function getTotalPaymentsCurrentYear()
    {   
        $payments = Payment::select(DB::raw("sum(amount) as data"))                
                ->whereYear('created_at', $this->year)
                ->where('status', 'Success')
                ->get();  
        
        return $payments;
    }


    public function getTotalPurchasedMinutesCurrentYear()
    {   
        $minutes = Payment::select(DB::raw("sum(minutes) as data"))
                ->whereYear('created_at', $this->year)
                ->where('status', 'Success')
                ->get();  
        
        return $minutes;
    }


    public function getTotalPaymentsCurrentMonth()
    {   
        $payments = Payment::select(DB::raw("sum(amount) as data"))
                ->whereMonth('created_at', $this->month)
                ->where('status', 'Success')
                ->get();  
        
        return $payments;
    }


    public function getTotalPaymentsPastMonth()
    {   
        $date = \Carbon\Carbon::now();
        $pastMonth =  $date->subMonth()->format('m');

        $payments = Payment::select(DB::raw("sum(amount) as data"))
                ->whereMonth('created_at', $pastMonth)
                ->where('status', 'Success')
                ->get();  
        
        return $payments;
    }


    public function getTotalPurchasedMinutesCurrentMonth()
    {   
        $minutes = Payment::select(DB::raw("sum(minutes) as data"))
                ->whereMonth('created_at', $this->month)
                ->where('status', 'Success')
                ->get();  
        
        return $minutes;
    }


    public function getTotalPurchasedMinutesPastMonth()
    {   
        $date = \Carbon\Carbon::now();
        $pastMonth =  $date->subMonth()->format('m');

        $minutes = Payment::select(DB::raw("sum(minutes) as data"))
                ->whereMonth('created_at', $pastMonth)
                ->where('status', 'Success')
                ->get();  
        
        return $minutes;
    }

}