<?php

namespace App\Services\Statistics;

use Illuminate\Support\Facades\Auth;
use App\Models\Result;
use DB;

class UserUsageYearlyService 
{
    private $year;

    public function __construct(int $year)
    {
        $this->year = $year;
    }


    public function getFileMinutesUsage($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $file_minutes = Result::select(DB::raw("sum(length) as data"), DB::raw("MONTH(created_at) month"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->where('mode', 'file')
                ->groupBy('month')
                ->orderBy('month')
                ->get()->toArray();  
        
        $data = [];

        for($i = 1; $i <= 12; $i++) {
            $data[$i] = 0;
        }

        foreach ($file_minutes as $row) {				            
            $month = $row['month'];
            $data[$month] = (number_format((float)$row['data']/60, 2));
        }
        
        return $data;
    }


    public function getRecordMinutesUsage($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $record_minutes = Result::select(DB::raw("sum(length) as data"), DB::raw("MONTH(created_at) as month"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->where('mode', 'record')
                ->groupBy('month')
                ->orderBy('month')
                ->get()->toArray();  
        
        $data = [];

        for($i = 1; $i <= 12; $i++) {
            $data[$i] = 0;
        }

        foreach ($record_minutes as $row) {				            
            $month = $row['month'];
            $data[$month] = (number_format((float)$row['data']/60, 2));
        }
        
        return $data;
    }


    public function getLiveMinutesUsage($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $live_minutes = Result::select(DB::raw("sum(length) as data"), DB::raw("MONTH(created_at) as month"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->where('mode', 'live')
                ->groupBy('month')
                ->orderBy('month')
                ->get()->toArray();  
        
        $data = [];

        for($i = 1; $i <= 12; $i++) {
            $data[$i] = 0;
        }

        foreach ($live_minutes as $row) {				            
            $month = $row['month'];
            $data[$month] = (number_format((float)$row['data']/60, 2));
        }
        
        return $data;
    }


    public function getTotalMinutes($user = null)
    {   
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $minutes = Result::select(DB::raw("sum(length) as data"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->get();  
        
        return $minutes;
    }


    public function getTotalWords($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $words = Result::select(DB::raw("sum(words) as data"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->get();  
        
        return $words;
    }

    
    public function getTotalFileTranscribe($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $files = Result::select(DB::raw("count(id) as data"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->where('mode', 'file')
                ->get();  
        
        return $files;
    }


    public function getTotalRecordingTranscribe($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $record = Result::select(DB::raw("count(id) as data"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->where('mode', 'record')
                ->get();  
        
        return $record;
    }


    public function getTotalLiveTranscribe($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $live = Result::select(DB::raw("count(id) as data"))
                ->whereYear('created_at', $this->year)
                ->where('user_id', $user_id)
                ->where('mode', 'live')
                ->get();  
        
        return $live;
    }


    public function getAllMinutesUsage($user = null)
    {
        $user_id = (is_null($user)) ? Auth::user()->id : $user;

        $chars = Result::select(DB::raw("sum(length) as data"))
                ->where('user_id', $user_id)
                ->get();  
        
        return $chars;
    }
}