@extends('layouts.app')
@section('css')
	<!-- Data Table CSS -->
	<link href="{{URL::asset('plugins/datatable/datatables.min.css')}}" rel="stylesheet" />
@endsection
@section('page-header')
<!-- PAGE HEADER -->
<div class="page-header mt-5-7">
	<div class="page-leftheader">
		<h4 class="page-title mb-0">{{ __('My Live Transcribe Results Data') }}</h4>
		<ol class="breadcrumb mb-2">
			<li class="breadcrumb-item"><a href="{{route('user.stt.file')}}"><i class="mdi mdi-audiobook mr-2 fs-12"></i>{{ __('User') }}</a></li>
			<li class="breadcrumb-item active" aria-current="page"><a href="{{url('#')}}"> {{ __('Live Transcribe Results') }}</a></li>
		</ol>
	</div>
</div>
<!-- END PAGE HEADER -->
@endsection
@section('content')	
	<div class="row">
		<div class="col-lg-12 col-md-12 col-sm-12 mt-5">
			<div class="card border-0">
				<div class="card-header">
					<h3 class="card-title">{{ __('All Live Transcribe Results') }}</h3>
					<a id="refresh-button" href="#" data-toggle="tooltip" data-placement="top" title="Refresh Table"><i class="fa fa-refresh transcribe-action-buttons transcribe-result"></i></a>
				</div>
				<div class="card-body pt-2">
					<!-- SET DATATABLE -->
					<table id='userResultTable' class='table' width='100%'>
							<thead>
								<tr>
									<th width="2%"></th>
									<th width="7%">{{ __('Created On') }}</th>									
									<th width="7%">{{ __('Project') }}</th>
									<th width="7%">{{ __('Task ID') }}</th>
									@if (config('stt.vendor_logos') == 'show') <th width="5%">{{ __('Vendor') }}</th> @endif
									<th width="7%">{{ __('Language') }}</th>							
									<th width="5%">{{ __('Words') }}</th>							
									<th width="5%">{{ __('Duration') }}</th>																									           	     						           	
									<th width="5%">{{ __('Mode') }}</th> 																           	     						           	
									<th width="3%">{{ __('Actions') }}</th>
								</tr>
							</thead>
					</table> <!-- END SET DATATABLE -->
				</div>
			</div>
		</div>
	</div>

	<!-- DELETE MODAL -->
	<div class="modal fade" id="deleteModal" tabindex="-1" role="dialog" aria-labelledby="deleteModalLabel" aria-hidden="true">
		<div class="modal-dialog modal-dialog-centered modal-md" role="document">
			<div class="modal-content">
				<div class="modal-header">
					<h4 class="modal-title" id="myModalLabel"><i class="mdi mdi-alert-circle-outline color-red"></i> {{ __('Confirm Result Deletion') }}</h4>
					<button type="button" class="close" data-dismiss="modal" aria-label="Close">
						<span aria-hidden="true">&times;</span>
					</button>
				</div>
				<div class="modal-body" id="deleteModalBody">
					<div>
						<!-- DELETE CONFIRMATION -->
					</div>
				</div>
			</div>
		</div>
	</div>
	<!-- END DELETE MODAL -->

	<!-- TRANSCRIBE MODAL -->
	<div class="modal fade transcript-modal" id="transcriptModal" tabindex="-1" role="dialog" aria-labelledby="exampleModalCenterTitle" aria-hidden="true">
		<div class="modal-dialog modal-dialog-centered modal-lg" role="document">
			<div class="modal-content">
				<div class="modal-header">
				<h5 class="modal-title" id="exampleModalLongTitle">Live Transcript Results</h5>
				<button type="button" class="close" data-dismiss="modal" aria-label="Close">
						<span aria-hidden="true">&times;</span>
				</button>
				</div>
				<div class="modal-buttons">
					<span><a href="#" id="live-download-txt" data-toggle="tooltip" data-placement="top" title="Download as Text File"><i class="fa fa-cloud-download"></i></a></span>
					<span><a href="#" id="live-save" data-id="" data-toggle="tooltip" data-placement="top" title="Save Edited Text"><i class="fa fa-floppy-o"></i></a></span>
				</div>
				<span class="save-status" id="live-save-status"></span>
				<div class="modal-body">
				<textarea class="form-control" id="textarea" rows="10" autofocus></textarea>
				</div>     
			</div>
		</div>
	</div> 
	<!-- TRANSCRIBE MODAL -->
@endsection

@section('js')
<!-- Data Tables JS -->
<script src="{{URL::asset('plugins/datatable/datatables.min.js')}}"></script>
<script src="{{URL::asset('js/results-live.js')}}"></script>
<script type="text/javascript">
	let table;
	$(function () {

		"use strict";
		
		function format(d) {
			// `d` is the original data object for the row
			return '<div class="slider">'+
						'<table class="details-table">'+
							'<tr>'+
								'<td class="details-title" width="10%">Transcript:</td>'+
								'<td>'+ ((d.text == null) ? '' : d.text) +'</td>'+
							'</tr>'+
						'</table>'+
					'</div>';
		}

		// INITILIZE DATATABLE
		let vendor_logo = JSON.parse(`<?php echo $vendor_logo['status']; ?>`);

		if ( vendor_logo == 'show') {
				table = $('#userResultTable').DataTable({
					"lengthMenu": [[25, 50, 100, -1], [25, 50, 100, "All"]],
					responsive: {
						details: {type: 'column'}
					},
					colReorder: true,
					language: {
						"emptyTable": "<div><img id='no-results-img' src='{{ URL::asset('img/files/no-result.png') }}'><br>No transcribe tasks submitted yet</div>",
						search: "<i class='fa fa-search search-icon'></i>",
						lengthMenu: '_MENU_ ',
						paginate : {
							first    : '<i class="fa fa-angle-double-left"></i>',
							last     : '<i class="fa fa-angle-double-right"></i>',
							previous : '<i class="fa fa-angle-left"></i>',
							next     : '<i class="fa fa-angle-right"></i>'
						}
					},
					pagingType : 'full_numbers',
					processing: true,
					serverSide: true,
					ajax: "{{ route('user.stt.results.live') }}",
					columns: [{
							"className":      'details-control',
							"orderable":      false,
							"searchable":     false,
							"data":           null,
							"defaultContent": ''
						},
						{
							data: 'created-on',
							name: 'created-on',
							orderable: true,
							searchable: true
						},						
						{
							data: 'project',
							name: 'project',
							orderable: true,
							searchable: true
						},	
						{
							data: 'task_id',
							name: 'task_id',
							orderable: true,
							searchable: true
						},
						{
							data: 'vendor',
							name: 'vendor',
							orderable: true,
							searchable: true
						},
						{
							data: 'custom-language',
							name: 'custom-language',
							orderable: true,
							searchable: true
						},		
						{
							data: 'words',
							name: 'words',
							orderable: true,
							searchable: true
						},									
						{
							data: 'custom-length',
							name: 'custom-length',
							orderable: true,
							searchable: true
						},	
						{
							data: 'custom-mode',
							name: 'custom-mode',
							orderable: true,
							searchable: true
						},				
						{
							data: 'actions',
							name: 'actions',
							orderable: false,
							searchable: false
						},
					]
				});
							
			} else {
			 	table = $('#userResultTable').DataTable({
					"lengthMenu": [[25, 50, 100, -1], [25, 50, 100, "All"]],
					responsive: {
						details: {type: 'column'}
					},
					colReorder: true,
					language: {
						"emptyTable": "<div><img id='no-results-img' src='{{ URL::asset('img/files/no-result.png') }}'><br>No transcribe tasks submitted yet</div>",
						search: "<i class='fa fa-search search-icon'></i>",
						lengthMenu: '_MENU_ ',
						paginate : {
							first    : '<i class="fa fa-angle-double-left"></i>',
							last     : '<i class="fa fa-angle-double-right"></i>',
							previous : '<i class="fa fa-angle-left"></i>',
							next     : '<i class="fa fa-angle-right"></i>'
						}
					},
					pagingType : 'full_numbers',
					processing: true,
					serverSide: true,
					ajax: "{{ route('user.stt.results.live') }}",
					columns: [{
							"className":      'details-control',
							"orderable":      false,
							"searchable":     false,
							"data":           null,
							"defaultContent": ''
						},
						{
							data: 'created-on',
							name: 'created-on',
							orderable: true,
							searchable: true
						},	
						{
							data: 'project',
							name: 'project',
							orderable: true,
							searchable: true
						},
						{
							data: 'task_id',
							name: 'task_id',
							orderable: true,
							searchable: true
						},
						{
							data: 'custom-language',
							name: 'custom-language',
							orderable: true,
							searchable: true
						},	
						{
							data: 'words',
							name: 'words',
							orderable: true,
							searchable: true
						},																			
						{
							data: 'custom-length',
							name: 'custom-length',
							orderable: true,
							searchable: true
						},					
						{
							data: 'custom-mode',
							name: 'custom-mode',
							orderable: true,
							searchable: true
						},
						{
							data: 'actions',
							name: 'actions',
							orderable: false,
							searchable: false
						},
					]
				});
			}

		$('#userResultTable tbody').on('click', 'td.details-control', function () {
			let tr = $(this).closest('tr');
			let row = table.row( tr );
	
			if ( row.child.isShown() ) {
				// This row is already open - close it
				$('div.slider', row.child()).slideUp( function () {
					row.child.hide();
					tr.removeClass('shown');
				} );
			}
			else {
				// Open this row
				row.child( format(row.data()), 'no-padding' ).show();
				tr.addClass('shown');
	
				$('div.slider', row.child()).slideDown();
			}
		});


		$('#refresh-button').on('click', function(e){
			e.preventDefault();
			$("#userResultTable").DataTable().ajax.reload();
		});
		
		
		// DELETE CONFIRMATION MODAL
		$(document).on('click', '#deleteResultButton', function(event) {
			event.preventDefault();
			let href = $(this).attr('href');
			$.ajax({
				url: href
				, beforeSend: function() {
					$('#loader').show();
				},
				// return the result
				success: function(result) {
					$('#deleteModal').modal("show");
					$('#deleteModalBody').html(result).show();
				}
				, error: function(jqXHR, testStatus, error) {
					console.log(error);
					alert("Page " + href + " cannot open. Error:" + error);
					$('#loader').hide();
				}
				, timeout: 8000
			})
		});

	});
</script>
@endsection